
import unittest

from robotworld import RobotWorld
from robot import Robot
from coordinates import Coordinates
import direction
from spinbot import Spinbot
from drunkbot import Drunkbot
from lovebot import Lovebot
from nosebot import Nosebot

class Test(unittest.TestCase):


    def setUp(self):
        self.test_world = RobotWorld(5, 5)
        wall_coordinates = Coordinates(2, 4)
        self.test_world.add_wall(wall_coordinates)

        first_location = Coordinates(4, 3)
        first_body = Robot('Bart')
        first_brain = Spinbot(first_body)
        first_body.set_brain(first_brain)
        self.test_world.add_robot(first_body, first_location, direction.EAST)

    
    def test_nosebot(self):
        '''
        Tests the nosebot movements.
        '''
        fifth_location = Coordinates(4, 4)
        fifth_body = Robot('Speedy Gonzales')
        fifth_brain = Nosebot(fifth_body)
        fifth_body.set_brain(fifth_brain)
        self.test_world.add_robot(fifth_body, fifth_location, direction.WEST)


        self.test_world.next_full_turn()
        self.test_world.next_full_turn()
        
        self.assertEqual('(3, 3)', str(self.test_world.get_robots()[1].get_location()),
                "the nosebot should be in (3, 3) after two moves")

        # WRITE MORE TESTS




    def test_drunkbot(self):
        '''
        Tests the drunkbot movements.
        '''
        fifth_location = Coordinates(4, 4)
        fifth_body = Robot('Speedy Gonzales')
        fifth_brain = Nosebot(fifth_body)
        fifth_body.set_brain(fifth_brain)
        self.test_world.add_robot(fifth_body, fifth_location, direction.WEST)

        second_location = Coordinates(2, 2)
        second_body = Robot('Homer')
        second_brain = Drunkbot(second_body, 4522)
        second_body.set_brain(second_brain)
        self.test_world.add_robot(second_body, second_location, direction.SOUTH)


        self.test_world.next_full_turn()
        self.test_world.next_full_turn()
        
        self.assertEqual('(3, 3)', str(self.test_world.get_robots()[1].get_location()),
                "the nosebot should be in (3, 3) after two moves")

        self.assertEqual('(2, 3)', str(self.test_world.get_robots()[2].get_location()),
                "the drunkbot should be in (2, 3) after two moves")
        
        self.assertTrue(self.test_world.get_robot(1).is_broken(), 
                        'the drunkbot collided with the nosebot, the nosebot should be broken')

        # WRITE MORE TESTS

    def test_lovebot(self):
        '''
        Tests the lovebot movements.
        '''

        second_location = Coordinates(2, 1)
        second_body = Robot('Homer')
        second_brain = Drunkbot(second_body, 4522)
        second_body.set_brain(second_brain)
        self.test_world.add_robot(second_body, second_location, direction.SOUTH)

        third_location = Coordinates(4, 0)
        third_body = Robot('Creepy')
        third_brain = Lovebot(third_body, second_body)
        third_body.set_brain(third_brain)
        self.test_world.add_robot(third_body, third_location, direction.NORTH)

        fourth_location = Coordinates(1, 1)
        fourth_body = Robot('Lwaxana')
        fourth_brain = Drunkbot(fourth_body, 7107)
        fourth_body.set_brain(fourth_brain)
        self.test_world.add_robot(fourth_body, fourth_location, direction.WEST)

        third_location = Coordinates(0, 2)
        third_body = Robot('Tog')
        third_brain = Lovebot(third_body, fourth_body)
        third_body.set_brain(third_brain)
        self.test_world.add_robot(third_body, third_location, direction.NORTH)




        self.test_world.next_full_turn()
        self.test_world.next_full_turn()
        

        # WRITE MORE TESTS



      

if __name__ == "__main__":
    #import sys;sys.argv = ['', 'Test.testName']
    unittest.main()
    

